import {
  select,
  json,
  csv,
  geoPath,
  geoAlbersUsa,
  geoMercator,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';
import { feature, mesh } from 'topojson';

const svg = select('svg');
//The geoMercator() function in d3.js is used 
//to draw The spherical Mercator projection.
const projection = geoMercator()
  .translate([-1000, -75]) // position
  .scale([650]); // zoom

// given a JSON geometry object, to generates an SVG path
const pathGenerator = geoPath().projection(projection);

//Array of ten categorical colors which is returned as RGB hexadecimal strings. 
const colorScale = scaleOrdinal(schemeCategory10);

//loading data
json('https://gist.githubusercontent.com/vagdevi-369/e37e83afffdab80d3c08ebd0e8603901/raw/8ac1345b8e4d0172ed4f77fe39fd7f123e3d3446/ICE-8'
).then((data) => {
  //extracting states data
  const countryShapes = feature(
    data,
    data.objects["2021_ELB_region"]
  );
  
countryShapes.features.shift()

	//Renders the path to a Canvas by appending path 
  //generated by pathgenerator to svg
  const customColors = ['Crimson', 'DarkOrchid', 'HotPink', 'LightCoral', 'Green', 'LightSalmon', 'MediumSlateBlue', 'RoyalBlue'];
  const colorScale = scaleOrdinal()
  .domain(['value1', 'value2', 'value3', 'value4', 'value5', 'value6', 'value7', 'value8'])
  .range(customColors);
  svg
    .selectAll('path')
    .data(countryShapes.features)
    .enter()
    .append('path')
    .attr('class', 'states')
    .attr('fill', (d) => { return(colorScale(d.properties.Elect_div))})
    .attr('d', (d) => pathGenerator(d))
    .append('title')
    .text((d) => d.properties.NAME_1);

 
});